import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';
import '../model/username_available_result.dart';
import 'app_api.dart';
import 'models/auth_industry.dart';
import 'models/check_email_result.dart';
import 'models/check_phone_result.dart';
import 'models/upload_thumbnail_result.dart';

enum CheckEmailType {
  updateEmail,
  registerNewUser,
  registerNewPro,
  forgotPassword,
  login
}

class AuthXRepo {
  AuthXRepo._();

  static AuthXRepo? _instance;

  factory AuthXRepo([MyAppApi? api]) {
    _instance ??= AuthXRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Future<CheckPhoneResult> checkPhone(params) async {
    NetworkResponse response = await _api.checkPhone(params);
    return response.data ?? CheckPhoneResult();
  }

  Future<CheckEmailResult> checkEmail(params) async {
    NetworkResponse response = await _api.checkEmail(params);
    return response.data ?? CheckEmailResult();
  }

  Future<ConfirmOtp?> verifyEmailOtp(params) async {
    NetworkResponse response = await _api.verifyEmailOtp(params);
    return response.data;
  }

  Future<NetworkResponse> loginByEmailVerifiedToken(params) async {
    return await _api.loginByEmailVerifiedToken(params);
  }

  Future<bool> updateNewEmailByEmailVerifiedToken(params) async {
    NetworkResponse response =
        await _api.updateNewEmailByEmailVerifiedToken(params);
    return response.data ?? false;
  }

  Future<bool> resetPasswordByEmailVerifiedToken(params) async {
    NetworkResponse response =
        await _api.resetPasswordByEmailVerifiedToken(params);
    return response.data ?? false;
  }

  Future<UploadThumbnalResult?> setThumbnailForUserOrPro(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForUserOrPro(image, filePath, callback);
    return response.data;
  }

  Future<ProInfo?> getProInfo([params]) async {
    NetworkResponse response = await _api.getProInfo(params);
    return response.data;
  }

  Future<UserModel?> getUserInfo([params]) async {
    NetworkResponse response = await _api.getUserInfo(params);
    return response.data;
  }

  Future<List<AuthIndustry>> getServiceCatForIndustry([params]) async {
    NetworkResponse response = await _api.getServiceCatForIndustry(params);
    return response.data ?? [];
  }

  Future loginTerminal({required params}) async {
    return await _api.loginTerminal(params);
  }

  Future<NetworkResponse> loginUserOrProByUsername(params) async {
    return await _api.loginUserOrProByUsername(params);
  }

  Future<TokenResponseLogin?> refreshToken(String refreshToken) async {
    NetworkResponse response = await _api.refreshToken(refreshToken);
    return response.data;
  }

  Future<UsernameAvailableResult?> checkUsernameAvailable(params) async {
    NetworkResponse response = await _api.checkUsernameAvailable(params);
    return response.data;
  }

  Future<TokenResponseLogin?> createNewPro(params) async {
    NetworkResponse response = await _api.createNewPro(params);
    return response.data;
  }

  Future<TokenResponseLogin?> createNewUser(params) async {
    NetworkResponse response = await _api.createNewUser(params);
    return response.data;
  }

  Future<bool> updateRegistrationLevelForUser(params) async {
    NetworkResponse response =
        await _api.updateRegistrationLevelForUser(params);
    return response.data ?? false;
  }

  Future<bool> updateRegistrationLevelForPro(params) async {
    NetworkResponse response = await _api.updateRegistrationLevelForPro(params);
    return response.data ?? false;
  }

  Future<UpdateInfoResult> updatePro(params) async {
    NetworkResponse response = await _api.updatePro(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<UpdateInfoResult> updateUser(params) async {
    NetworkResponse response = await _api.updateUser(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<UpdateInfoResult> updatePassword(
      {required String oldPassword, required String newPassword}) async {
    NetworkResponse response =
        await _api.updatePassword(oldPassword, newPassword);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<List<LoginSession>> getLoginSessions(params) async {
    NetworkResponse response = await _api.getLoginSessions(params);
    return response.data ?? [];
  }

  Future<LoginSession?> getLoginSessionsById(params) async {
    NetworkResponse response = await _api.getLoginSessionsById(params);
    return response.data;
  }

  Future<bool> revokeLoginSession(params) async {
    NetworkResponse response = await _api.revokeLoginSession(params);
    return response.data ?? false;
  }

  Future<bool> allowPendingLoginOnPlatformByQrCode(params) async {
    NetworkResponse response =
        await _api.allowPendingLoginOnPlatformByQrCode(params);
    return response.data ?? false;
  }

  Future<bool> allowPendingLoginOnPlatformById(params) async {
    NetworkResponse response =
        await _api.allowPendingLoginOnPlatformById(params);
    return response.data ?? false;
  }
}
