import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core_network/utils.dart';
import 'package:dio/dio.dart';

import 'models/legal_menu.dart';
import 'models/legal_platform.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getLegalContent() => "v2/legal/getLegalContent";
  static String gptTranslateLegal() => "v2/legal/gptTranslateLegal";
  static String getListOfLegalPlatformFromAdmin() =>
      "v2/legal/getListOfLegalPlatformFromAdmin";
  static String getLegalFromAdmin() => "v2/legal/getLegalFromAdmin";
  static String acceptTerms() => "v2/legal/acceptTerms";
  static String createLegal() => "v2/legal/createLegal";
  static String updateLegal() => "v2/legal/updateLegal";
  static String deleteLegalFromAdmin() => "v2/legal/deleteLegalFromAdmin";
  static String getLegalMenusFromPlatformId() =>
      "v2/legal/getLegalMenusFromPlatformId";
}

abstract class MyAppApi {
  Future<NetworkResponse> getLegalContent(params);
  Future<NetworkResponse> gptTranslateLegal(params);
  Future<NetworkResponse> getListOfLegalPlatformFromAdmin(params);
  Future<NetworkResponse> getLegalFromAdmin(params);
  Future<NetworkResponse> acceptTerms(params);
  Future<NetworkResponse> createLegal(params);
  Future<NetworkResponse> updateLegal(params);
  Future<NetworkResponse> deleteLegalFromAdmin(params);
  Future<NetworkResponse> getLegalMenusFromPlatformId(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getLegalContent(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(requiredToken: false)
            .get(_MyAppEndpoint.getLegalContent(), queryParameters: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) => LegalInfo.fromJson(json));
      },
    );
  }

  @override
  Future<NetworkResponse> gptTranslateLegal(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true,
                token: await appPrefs.getNormalToken(),
                connectTimeout: const Duration(seconds: 120),
                receiveTimeout: const Duration(seconds: 60))
            .get(_MyAppEndpoint.gptTranslateLegal(), queryParameters: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) => LegalInfo.fromJson(json));
      },
    );
  }

  @override
  Future<NetworkResponse> getListOfLegalPlatformFromAdmin(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .get(_MyAppEndpoint.getListOfLegalPlatformFromAdmin(),
                queryParameters: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) =>
                (json as List).map((e) => LegalPlatform.fromJson(e)).toList());
      },
    );
  }

  @override
  Future<NetworkResponse> getLegalFromAdmin(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .get(_MyAppEndpoint.getLegalFromAdmin(), queryParameters: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) =>
                (json as List).map((e) => LegalInfo.fromJson(e)).toList());
      },
    );
  }

  @override
  Future<NetworkResponse> acceptTerms(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .post(_MyAppEndpoint.acceptTerms(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> createLegal(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .post(_MyAppEndpoint.createLegal(), data: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) => LegalInfo.fromJson(json));
      },
    );
  }

  @override
  Future<NetworkResponse> updateLegal(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .put(_MyAppEndpoint.updateLegal(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> deleteLegalFromAdmin(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(
                requiredToken: true, token: await appPrefs.getNormalToken())
            .delete(_MyAppEndpoint.deleteLegalFromAdmin(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> getLegalMenusFromPlatformId(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(requiredToken: false).get(
            _MyAppEndpoint.getLegalMenusFromPlatformId(),
            queryParameters: params);
        return NetworkResponse.fromResponse(
          response,
          converter: (json) =>
              (json as List).map((e) => LegalMenu.fromJson(e)).toList(),
        );
      },
    );
  }
}
