import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/options.dart';
import 'package:dio/dio.dart' as dio;

class NetworkResponse<T> {
  static String disconnectError = 'disconnectError';
  static String unknownError = 'unknownError';

  String get responsePrefixData =>
      networkOptions.responsePrefixData ?? "values";

  int? statusCode;
  bool? status;
  T? data;
  String? msg;

  bool get isSuccess => networkOptions.responseIsSuccess != null
      ? networkOptions.responseIsSuccess!(this)
      : (statusCode == 200 && data != null);

  bool get isErrorConnection => this.msg == disconnectError;

  bool get isError => isErrorConnection || statusCode != 200;

  NetworkResponse({this.data, this.statusCode, this.msg});

  factory NetworkResponse.fromResponse(dio.Response response,
      {converter, value, String? prefix}) {
    try {
      return NetworkResponse._fromJson(response.data,
          converter: converter, prefix: prefix, value: value)
        ..statusCode = response.statusCode;
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  NetworkResponse._fromJson(dynamic json, {converter, value, String? prefix}) {
    try {
      status = json["status"] is bool ? json["status"] : null;
    } catch (_) {}
    if (value != null) {
      data = value;
    } else if (prefix != null) {
      if (prefix.trim().isEmpty) {
        data = converter != null && json != null ? converter(json) : json;
      } else {
        data = converter != null && json[prefix] != null
            ? converter(json[prefix])
            : json[prefix];
      }
    } else {
      data = converter != null && json[responsePrefixData] != null
          ? converter(json[responsePrefixData])
          : json[responsePrefixData];
    }
  }

  NetworkResponse.withErrorRequest(dio.DioException error) {
    appDebugPrint("NetworkResponse.withErrorRequest: $error");
    try {
      data = null;
      status = false;
      dio.Response? response = error.response;
      statusCode = response?.statusCode ?? 500;
      if (response?.data?['error'] is String) {
        this.msg = response?.data?['error'];
      }
    } catch (e) {
      appDebugPrint("NetworkResponse.withErrorRequest2: $e");
    }
  }

  NetworkResponse.withErrorConvert(error) {
    appDebugPrint("NetworkResponse.withErrorConvert: $error");
    data = null;
    status = false;
    this.msg = unknownError;
  }

  NetworkResponse.withDisconnect() {
    appDebugPrint("NetworkResponse.withDisconnect");
    data = null;
    status = false;
    this.msg = disconnectError;
  }
}
