enum SportProgramsStatus { none, paused, completed }

class SportPrograms {
  String? id;
  int? cardType;
  int? numberOfExercices;
  int? totalDuration;
  int? programOwnerProId;
  int? programPropertyId;
  int? isPublished;
  String? programPictureUrl;
  String? name;
  String? description;
  List<ProgramContents>? programContents;
  ProgramProperty? programProperty;

  SportProgramsStatus get status {
    if (programContents!.any((e) => e.pausedTime != null)) {
      return SportProgramsStatus.paused;
    }
    if (!programContents!.any((e) => e.isCompleted == false)) {
      return SportProgramsStatus.completed;
    }
    return SportProgramsStatus.none;
  }

  int get indexPaused {
    if (status == SportProgramsStatus.paused) {
      return programContents!
          .indexOf(programContents!.firstWhere((e) => e.pausedTime != null));
    }
    return 0;
  }

  SportPrograms(
      {this.id,
      this.cardType,
      this.numberOfExercices,
      this.totalDuration,
      this.programOwnerProId,
      this.programPropertyId,
      this.isPublished,
      this.programPictureUrl,
      this.name,
      this.description,
      this.programContents,
      this.programProperty});

  SportPrograms.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["cardType"] is int) cardType = json["cardType"];
    if (json["numberOfExercices"] is int) {
      numberOfExercices = json["numberOfExercices"];
    }
    if (json["totalDuration"] is int) {
      totalDuration = json["totalDuration"];
    }
    if (json["programOwnerProId"] is int) {
      programOwnerProId = json["programOwnerProId"];
    }
    if (json["programPropertyId"] is int) {
      programPropertyId = json["programPropertyId"];
    }
    if (json["isPublished"] is int) isPublished = json["isPublished"];
    if (json["programPictureUrl"] is String) {
      programPictureUrl = json["programPictureUrl"];
    }
    if (json["name"] is String) name = json["name"];
    if (json["description"] is String) description = json["description"];
    if (json["programContents"] is List) {
      programContents = json["programContents"] == null
          ? null
          : (json["programContents"] as List)
              .map((e) => ProgramContents.fromJson(e))
              .toList();
    }
    if (json["programProperty"] is Map) {
      programProperty = json["programProperty"] == null
          ? null
          : ProgramProperty.fromJson(json["programProperty"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["cardType"] = cardType;
    data["numberOfExercices"] = numberOfExercices;
    data["totalDuration"] = totalDuration;
    data["programOwnerProId"] = programOwnerProId;
    data["programPropertyId"] = programPropertyId;
    data["isPublished"] = isPublished;
    data["programPictureUrl"] = programPictureUrl;
    data["name"] = name;
    data["description"] = description;
    if (programContents != null) {
      data["programContents"] =
          programContents?.map((e) => e.toJson()).toList();
    }
    if (programProperty != null) {
      data["programProperty"] = programProperty?.toJson();
    }
    return data;
  }
}

class ProgramProperty {
  int? id;
  String? slug;
  String? video;
  String? lat;
  String? lng;
  String? content;
  String? address;

  ProgramProperty(
      {this.id,
      this.slug,
      this.video,
      this.lat,
      this.lng,
      this.content,
      this.address});

  ProgramProperty.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) id = json["id"];
    if (json["slug"] is String) slug = json["slug"];
    if (json["video"] is String) video = json["video"];
    if (json["lat"] is String) lat = json["lat"];
    if (json["lng"] is String) lng = json["lng"];
    if (json["content"] is String) content = json["content"];
    if (json["address"] is String) address = json["address"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["slug"] = slug;
    data["video"] = video;
    data["lat"] = lat;
    data["lng"] = lng;
    data["content"] = content;
    data["address"] = address;
    return data;
  }
}

class ProgramContents {
  String? id;
  int? subcardOrderNumber;
  String? subcardPictureUrl;
  int? exerciceDuration;
  dynamic breakAfter;
  int? numberOfRepetitions;
  dynamic values;
  int? breakBetweenRep;
  dynamic numberOfSeries;
  dynamic materialPictureUrl;
  dynamic exLottieUrl;
  dynamic exGifUrl;
  dynamic exVideoUrl;
  int? isBreak;
  String? subcardTitle;
  String? description;
  String? subcardVideoUrl;
  dynamic materialDescription;

  int? startedTime;
  int? pausedTime;
  int pausedDuration = 0;
  bool isCompleted = false;

  ProgramContents({
    this.id,
    this.subcardOrderNumber,
    this.subcardPictureUrl,
    this.exerciceDuration,
    this.breakAfter,
    this.numberOfRepetitions,
    this.values,
    this.breakBetweenRep,
    this.numberOfSeries,
    this.materialPictureUrl,
    this.exLottieUrl,
    this.exGifUrl,
    this.exVideoUrl,
    this.isBreak,
    this.subcardTitle,
    this.description,
    this.subcardVideoUrl,
    this.materialDescription,
    this.isCompleted = false,
  });

  ProgramContents.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["subcardOrderNumber"] is int) {
      subcardOrderNumber = json["subcardOrderNumber"];
    }
    if (json["subcardPictureUrl"] is String) {
      subcardPictureUrl = json["subcardPictureUrl"];
    }
    if (json["exerciceDuration"] is int) {
      exerciceDuration = json["exerciceDuration"];
    }
    breakAfter = json["breakAfter"];
    if (json["numberOfRepetitions"] is int) {
      numberOfRepetitions = json["numberOfRepetitions"];
    }
    values = json["values"];
    if (json["breakBetweenRep"] is int) {
      breakBetweenRep = json["breakBetweenRep"];
    }
    numberOfSeries = json["numberOfSeries"];
    materialPictureUrl = json["materialPictureUrl"];
    exLottieUrl = json["exLottieUrl"];
    exGifUrl = json["exGifUrl"];
    exVideoUrl = json["exVideoUrl"];
    if (json["isBreak"] is int) isBreak = json["isBreak"];
    if (json["subcardTitle"] is String) {
      subcardTitle = json["subcardTitle"];
    }
    if (json["description"] is String) description = json["description"];
    if (json["subcardVideoUrl"] is String) {
      subcardVideoUrl = json["subcardVideoUrl"];
    }
    materialDescription = json["materialDescription"];
    startedTime = json["startedTime"];
    pausedTime = json["pausedTime"];
    pausedDuration = json["pausedDuration"] ?? 0;
    isCompleted = json["isCompleted"] ?? false;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["subcardOrderNumber"] = subcardOrderNumber;
    data["subcardPictureUrl"] = subcardPictureUrl;
    data["exerciceDuration"] = exerciceDuration;
    data["breakAfter"] = breakAfter;
    data["numberOfRepetitions"] = numberOfRepetitions;
    data["values"] = values;
    data["breakBetweenRep"] = breakBetweenRep;
    data["numberOfSeries"] = numberOfSeries;
    data["materialPictureUrl"] = materialPictureUrl;
    data["exLottieUrl"] = exLottieUrl;
    data["exGifUrl"] = exGifUrl;
    data["exVideoUrl"] = exVideoUrl;
    data["isBreak"] = isBreak;
    data["subcardTitle"] = subcardTitle;
    data["description"] = description;
    data["subcardVideoUrl"] = subcardVideoUrl;
    data["materialDescription"] = materialDescription;
    data["startedTime"] = startedTime;
    data["pausedTime"] = pausedTime;
    data["pausedDuration"] = pausedDuration;
    data["isCompleted"] = isCompleted;
    return data;
  }
}
