import '../resources.dart';

class AppointmentRepo {
  AppointmentRepo._();

  static AppointmentRepo? _instance;

  factory AppointmentRepo([AppApi? api]) {
    _instance ??= AppointmentRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api; 

  Future<EventQueueModel?> getQueueInfoFromUser(ticketUniqueId) async {
    NetworkResponse response = await _api.getQueueInfoFromUser(ticketUniqueId);
    return response.data;
  }

  Future<bool> cancelTicketByUser(String ticketUniqueId) async {
    NetworkResponse response =
        await _api.cancelTicketByUser(ticketUniqueId, 0, 'comment');
    return response.data ?? false;
  }

  Future<TicketInfoModel?> confirmTicketByUser(
      String ticketUniqueId, int status, String? comment) async {
    NetworkResponse response =
        await _api.confirmTicketByUser(ticketUniqueId, status, comment);
    return response.data;
  }

  Future<TicketInfoModel?> ticketUserCallBack(
      String ticketUniqueId, int duration) async {
    NetworkResponse response =
        await _api.ticketUserCallBack(ticketUniqueId, duration);
    return response.data;
  }

  Future<bool> deleteEventsFromUser(String ticketUniqueId) async {
    NetworkResponse response = await _api.deleteEventsFromUser(ticketUniqueId);
    return response.data ?? false;
  }

  Future<List<ProServiceModel>?> getAllServicesOfProFromPro(proId) async {
    NetworkResponse response =
        await _api.getAllServicesOfProFromPro({'proId': proId});
    return response.data;
  } 

  Future<List<ServiceDelayModel>?> updateDelay(params) async {
    NetworkResponse response = await _api.updateDelay(params);
    return response.data;
  }

  Future<bool> cancelTicketByPro(ticketUniqueId) async {
    NetworkResponse response = await _api.cancelTicketByPro(ticketUniqueId);
    return response.data ?? false;
  }

  Future<EventInfoModel?> confirmTicketByPro(
      String ticketUniqueId, int status, String? comment) async {
    NetworkResponse response =
        await _api.confirmTicketByPro(ticketUniqueId, status, comment);
    return response.data;
  }

  Future<EventInfoModel?> canceledByProAfterCallBack(
      String ticketUniqueId) async {
    NetworkResponse response =
        await _api.canceledByProAfterCallBack(ticketUniqueId);
    return response.data;
  }

  Future<bool> declareUserAsAbsentFromPro(String ticketUniqueId) async {
    NetworkResponse response =
        await _api.declareUserAsAbsentFromPro(ticketUniqueId);
    return response.data ?? false;
  }

  Future<bool> ticketUserNotResponse(String ticketUniqueId) async {
    NetworkResponse response = await _api.ticketUserNotResponse(ticketUniqueId);
    return response.data ?? false;
  }

  Future<bool> startTicket(String ticketUniqueId) async {
    NetworkResponse response = await _api.startTicket(ticketUniqueId);
    return response.data ?? false;
  }

  Future<bool> stopTicket(ticketUniqueId) async {
    NetworkResponse response = await _api.stopTicket(ticketUniqueId);
    return response.data ?? false;
  }

  Future<TicketInfoModel?> callNextTicket(serviceId) async {
    NetworkResponse response = await _api.callNextTicket(serviceId);
    return response.data;
  }

  Future<ListTimeFrameModel?> getListTimeFramesByServiceForDay(
      String dateToday, int serviceId) async {
    NetworkResponse response =
        await _api.getListTimeFramesByServiceForDay(dateToday, serviceId);
    return response.data;
  }

  Future<List<ServiceAvailabilityModel>?> getServiceAvailabilityForMonth(
      params) async {
    NetworkResponse response =
        await _api.getServiceAvailabilityForMonth(params);
    return response.data;
  }

  Future<TicketInfoModel?> createTicketByPro(params) async {
    NetworkResponse response = await _api.createTicketByPro(params);
    return response.data;
  }

  Future<bool> deleteEventsFromPro(String ticketUniqueId) async {
    NetworkResponse response = await _api.deleteEventsFromPro(ticketUniqueId);
    return response.data ?? false;
  }
}
